.. _intro-install:

==================
Installation guide
==================

Installing xpaw
===============

安装xpaw需要Python 3.5及更高版本的环境支持。

可以直接使用如下命令通过PyPI安装::

    pip install xpaw

也可使用如下命令通过源码安装::

    python setup.py install

如果安装过程中遇到lxml安装失败的情况，可参考 `lxml installation`_ 。

.. _lxml installation: http://lxml.de/installation.html

Requirements
============

- `aiohttp`_
- `pyyaml`_
- `lxml`_

.. _aiohttp: https://pypi.python.org/pypi/aiohttp
.. _pyyaml: https://pypi.python.org/pypi/pyyaml
.. _lxml: https://pypi.python.org/pypi/lxml
